
TODO: TODO_91_90_42_61: complete parsing and interpretation tests

There are a lot of test cases to cover with combinations of:
*   FS_20_88_05_60 `dictated_arg`-s
*   FS_97_64_39_94 `token_bucket`-s

In particular, suggestions should depend on which `token_bucket` is occupied by the cursor.
